==> 3.6.2.tar.gz: xbackbone/resources/lang/tr.lang.php <==
<?php
return [
    'orphaned_files' => 'Sahipsiz Dosyalar',
    'files' => 'Dosyalar',
    'hide' => 'Gizle',
    'publish' => 'Yayınla',
    'delete' => 'Sil',
    'upload' => 'Yükle',
    'download' => 'İndir',
    'raw' => 'Kaynak göster',
    'date' => 'Tarih',
    'owner' => 'Sahip',
    'public' => 'Herkese açık',
    'size' => 'Boyut',
    'filename' => 'Dosya adı',
    'preview' => 'Ön izleme',
    'public.delete_text' => 'Bu ögeyi silmek istediğinizden emin misiniz? Geri dönüşü olmayacaktır',
    'public.telegram' => 'Telegram\'da paylaş !',
    'copy_link' => 'Bağlantıyı kopyala',
    'pager.previous' => 'Önceki',
    'pager.next' => 'Sonraki',
    'logout' => 'Oturumu kapat',
    'profile' => 'Profil',
    'system' => 'Sistem',
    'users' => 'Kullanıcılar',
    'home' => 'Ana sayfa',
    'username' => 'Kullanıcı adı',
    'login' => 'Oturum aç',
    'password' => 'Parola',
    'login.username' => 'Kullanıcı adı veya e-posta',
    'no_media' => 'Medya ortamı bulunamadı.',
    'send' => 'Gönder',
    'no' => 'Hayır',
    'yes' => 'Evet',
    'enforce_language' => 'Dili uygula',
    'lang' => 'Türkçe',
    'copy' => 'Kopyala',
    'token' => 'Belirteç',
    'your_profile' => 'Profiliniz',
    'is_admin' => 'Yönetici mi',
    'is_active' => 'Etkin mi',
    'user.edit' => 'Kullanıcıyı düzenle',
    'user.create' => 'Kullanıcı oluştur',
    'system_settings' => 'Sistem Ayarları',
    'php_info' => 'PHP Bilgileri',
    'used' => 'Kullanılan',
    'save' => 'Kaydet',
    'apply' => 'Uygula',
    'click_to_load' => 'Yüklemek için tıklayın…',
    'theme' => 'Tema',
    'username_taken' => 'Kullanıcı adı zaten alınmış.',
    'password_required' => 'Parola gerekli.',
    'reg_date' => 'Kayıt Tarihi',
    'active' => 'Etkin',
    'none' => 'Yok',
    'open' => 'Açık',
    'admin' => 'Yönetici',
    'copied' => 'Panoya kopyalandı!',
    'update' => 'Güncelle',
    'edit' => 'Düzenle',
    'client_config' => 'İstemci Yapılandırması',
    'user_code' => 'Kullanıcı kodu',
    'confirm_string' => 'Emin misiniz?',
    'installed' => 'Kurulum başarıyla tamamlandı!',
    'bad_login' => 'Yanlış kimlik bilgileri.',
    'account_disabled' => 'Hesabınız devre dışı bırakıldı.',
    'welcome' => 'Hoş geldiniz, %s!',
    'goodbye' => 'Hoşça kal!',
    'token_not_found' => 'Belirtilen belirteç bulunamadı.',
    'email_required' => 'E-posta adresi gerekli.',
    'email_taken' => 'Bu e-posta adresi zaten kullanılıyor.',
    'username_required' => 'Kullanıcı adı gerekli.',
    'image_embeds' => 'Gömülü görüntü',
    'default_lang_behavior' => 'XBackBone varsayılan olarak tarayıcı diliyle eşleşmeye çalışacaktır (yedek dil İngilizce\'dir).',
    'no_upload_token' => 'Kişisel bir yükleme belirteciniz yok. (Bir tane oluşturun ve tekrar deneyin.)',
    'copy_url_behavior' => 'URL\'i kopyalama modu',
    'delete_all' => 'Hepsini Sil',
    'max_user_quota' => 'Azami Kullanıcı Kotası',
    'mail.recover_text' => 'Merhaba %s,<br>hesabınız için bir parola sıfırlama istendi. İşlemleri tamamlamak için aşağıdaki bağlantıya tıklayın:<br><br><a href="%s">%s</a><br><br>Parola sıfırlamayı isteyen siz değilseniz bu e-postayı dikkate almayın.',
    'clear_account' => 'Hesabı Temizle',
    'mail.new_account_text_with_pw' => 'Merhaba %s!<br>, %s (<a href="%s">%s</a>) tarihinde sizin için aşağıdaki kimlik bilgileriyle yeni bir hesap oluşturuldu:<br><br>Kullanıcı adı: %s<br>Parola: %s<br><br>Oturum açma sayfasına gitmek için aşağıdaki bağlantıya tıklayın:<br><a href="%s">%s</a>',
    'upload_max_file_size' => 'Azami dosya boyutu şu anda %s.',
    'recover_email_sent' => 'Varsa, belirtilen hesaba bir kurtarma e-postası gönderildi.',
    'cannot_demote' => 'Kendinizi rütbenizi indiremezsiniz.',
    'cannot_write_file' => 'Hedef yol yazılabilir değil.',
    'deleted_orphans' => '%d sahipsiz dosya başarıyla silindi.',
    'gallery' => 'Galeri',
    'table' => 'Tablo',
    'dotted_search' => 'Ara…',
    'time' => 'Zaman',
    'name' => 'Ad',
    'maintenance' => 'Bakım',
    'path_not_writable' => 'Çıkış yolu yazılabilir değil.',
    'already_latest_version' => 'Zaten son sürüme sahipsiniz.',
    'new_version_available' => 'Yeni %s sürümü var!',
    'cannot_retrieve_file' => 'Dosya alınamıyor.',
    'file_size_no_match' => 'İndirilen dosya doğru dosya boyutu ile eşleşmiyor.',
    'check_for_updates' => 'Güncellemeleri denetle',
    'upgrade' => 'Güncelle',
    'updates' => 'Güncellemeler',
    'maintenance_in_progress' => 'Platform bakımda, daha sonra tekrar deneyin…',
    'cancel' => 'İptal',
    'auto_set' => 'Otomatik olarak ayarla',
    'prerelease_channel' => 'Ön Yayın Kanalı',
    'drop_to_upload' => 'Yüklemek için dosyalarınızı buraya bırakın veya tıklayın.',
    'donation' => 'Bağış',
    'donate_text' => 'XBackBone\'u beğendiyseniz, geliştirmeyi desteklemek için bir bağış yapmayı düşünün!',
    'custom_head_html_hint' => 'Bu içerik her sayfanın <head> etiketine eklenecek.',
    'remember_me' => 'Beni hatırla',
    'please_wait' => 'Lütfen bekleyin…',
    'dont_close' => 'Tamamlanana kadar bu sekmeyi kapatmayın.',
    'register_enabled' => 'Kayıtlar etkinleştirildi',
    'hide_by_default' => 'Varsayılan olarak medyayı gizle',
    'settings_saved' => 'Sistem ayarları kaydedildi!',
    'export_data' => 'Veriyi dışarı çıkar',
    'password_recovery' => 'Parolayı kurtar',
    'no_account' => 'Hesabınız yok mu?',
    'register' => 'Kaydol',
    'register_success' => 'Hesap oluşturuldu, bir onay e-postası gönderildi.',
    'default_user_quota' => 'Varsayılan Kullanıcı Kotası',
    'invalid_quota' => 'Varsayılan kullanıcı kotası geçersiz değer.',
    'mail.activate_account' => '%s - Hesap Etkinleştirme',
    'mail.recover_password' => '%s - Parola Kurtarma',
    'account_activated' => 'Hesap etkinleştirildi, artık oturum açabilirsiniz!',
    'quota_enabled' => 'Kullanıcı kotasını etkinleştir',
    'password_repeat' => 'Parolayı Tekrarla',
    'password_match' => 'Parola ve tekrarlanan parola aynı olmalıdır.',
    'password_restored' => 'Parola sıfırlandı.',
    'recalculate_user_quota' => 'Diskten kullanıcı kotasını yeniden hesapla',
    'quota_recalculated' => 'Diskten kullanıcı kotası başarıyla yeniden hesaplandı.',
    'used_space' => 'Kullanılan Alan',
    'delete_selected' => 'Seçilenleri Sil',
    'account_media_deleted' => 'Hesaptaki tüm medya silindi.',
    'danger_zone' => 'Tehlike Bölgesi',
    'recaptcha_failed' => 'reCAPTCHA Başarısız oldu',
    'recaptcha_enabled' => 'reCAPTCHA etkinleştirildi',
    'recaptcha_keys_required' => 'Bütün reCAPTCHA anahtarları gerekli.',
    'only_recaptcha_v3' => 'Yalnızca reCAPTCHA v3 desteklenmektedir.',
    'recaptcha_site_key' => 'reCAPTCHA Site Anahtarı',
    'recaptcha_secret_key' => 'reCAPTCHA Gizli Anahtarı',
    'send_notification' => 'E-posta Bildirimi Gönder',
    'mail.new_account' => '%s - Yeni Hesap Oluşturma',
    'mail.new_account_text_with_reset' => 'Merhaba %s!<br>, %s (<a href="%s">%s</a>) tarihinde sizin için yeni bir hesap oluşturuldu, bir parola belirlemek ve etkinleştirmek için aşağıdaki bağlantıya tıklayın:<br><br><a href="%s">%s</a>',
    'user_create_password' => 'Boş bırakılırsa, kullanıcı e-posta adresine bir bildirim göndermek isteyebilirsiniz.',
    'ldap_cant_connect' => 'LDAP kimlik doğrulama sunucusuna bağlanılamıyor.',
    'no_tags' => 'Etiket eklenmedi',
    'auto_tagging' => 'Otomatik yükleme etiketleme',
    'zip_ext_not_loaded' => 'Gereken "zip" eklentisi yüklenmedi',
    'changelog' => 'Değişiklik Günlüğü (Yama Notları)',
    'show_changelog' => 'Değişiklik günlüğünü göster',
    'confirm' => 'Onay',
    'user_created' => '"%s" kullanıcısı oluşturuldu!',
    'user_updated' => '"%s" kullanıcısı güncellendi!',
    'profile_updated' => 'Profil başarıyla güncellendi!',
    'user_deleted' => 'Kullanıcı silindi.',
    'cannot_delete' => 'Kendi kullanıcınızı silemezsiniz.',
    'order_by' => 'Sıralama ölçütü…',
    'clean_orphaned_uploads' => 'Sahipsiz Yüklemeleri Temizle',
    'custom_head_html' => 'Özel HTML başlık içeriği',
    'custom_head_set' => 'Özel HTML başlığı uygulandı.',
    'mail.activate_text' => 'Merhaba %s!<br>%s (<a href="%s">%s</a>) hesabınızı oluşturduğunuz için teşekkür ederiz, etkinleştirmek için aşağıdaki bağlantıya tıklayın:<br><br><a href="%s">%s</a>',
    'switch_to' => 'Şuna geç',
];

==> 3.7.0.tar.gz: xbackbone/resources/lang/tr.lang.php <==
<?php
return [
    'orphaned_files' => 'Sahipsiz Dosyalar',
    'files' => 'Dosyalar',
    'hide' => 'Gizle',
    'publish' => 'Yayınla',
    'delete' => 'Sil',
    'upload' => 'Yükle',
    'download' => 'İndir',
    'raw' => 'Kaynak göster',
    'date' => 'Tarih',
    'owner' => 'Sahip',
    'public' => 'Herkese açık',
    'size' => 'Boyut',
    'filename' => 'Dosya adı',
    'preview' => 'Ön izleme',
    'public.delete_text' => 'Bu ögeyi silmek istediğinizden emin misiniz? Geri dönüşü olmayacaktır',
    'public.telegram' => 'Telegram\'da paylaş',
    'copy_link' => 'Bağlantıyı kopyala',
    'pager.previous' => 'Önceki',
    'pager.next' => 'Sonraki',
    'logout' => 'Oturumu kapat',
    'profile' => 'Profil',
    'system' => 'Sistem',
    'users' => 'Kullanıcılar',
    'home' => 'Ana sayfa',
    'username' => 'Kullanıcı adı',
    'login' => 'Oturum aç',
    'password' => 'Parola',
    'login.username' => 'Kullanıcı adı veya e-posta',
    'no_media' => 'Medya ortamı bulunamadı.',
    'send' => 'Gönder',
    'no' => 'Hayır',
    'yes' => 'Evet',
    'enforce_language' => 'Dili uygula',
    'lang' => 'Türkçe',
    'copy' => 'Kopyala',
    'token' => 'Belirteç',
    'your_profile' => 'Profiliniz',
    'is_admin' => 'Yönetici mi',
    'is_active' => 'Etkin mi',
    'user.edit' => 'Kullanıcıyı düzenle',
    'user.create' => 'Kullanıcı oluştur',
    'system_settings' => 'Sistem Ayarları',
    'php_info' => 'PHP Bilgileri',
    'used' => 'Kullanılan',
    'save' => 'Kaydet',
    'apply' => 'Uygula',
    'click_to_load' => 'Yüklemek için tıklayın…',
    'theme' => 'Tema',
    'username_taken' => 'Kullanıcı adı zaten alınmış.',
    'password_required' => 'Parola gerekli.',
    'reg_date' => 'Kayıt Tarihi',
    'active' => 'Etkin',
    'none' => 'Yok',
    'open' => 'Açık',
    'admin' => 'Yönetici',
    'copied' => 'Panoya kopyalandı!',
    'update' => 'Güncelle',
    'edit' => 'Düzenle',
    'client_config' => 'İstemci Yapılandırması',
    'user_code' => 'Kullanıcı kodu',
    'confirm_string' => 'Emin misiniz?',
    'installed' => 'Kurulum başarıyla tamamlandı!',
    'bad_login' => 'Yanlış kimlik bilgileri.',
    'account_disabled' => 'Hesabınız devre dışı bırakıldı.',
    'welcome' => 'Hoş geldiniz, %s!',
    'goodbye' => 'Hoşça kal!',
    'token_not_found' => 'Belirtilen belirteç bulunamadı.',
    'email_required' => 'E-posta adresi gerekli.',
    'email_taken' => 'Bu e-posta adresi zaten kullanılıyor.',
    'username_required' => 'Kullanıcı adı gerekli.',
    'image_embeds' => 'Gömülü görüntü',
    'default_lang_behavior' => 'XBackBone varsayılan olarak tarayıcı diliyle eşleşmeye çalışacaktır (yedek dil İngilizce\'dir).',
    'no_upload_token' => 'Kişisel bir yükleme belirteciniz yok. (Bir tane oluşturun ve tekrar deneyin.)',
    'copy_url_behavior' => 'URL\'i kopyalama modu',
    'delete_all' => 'Hepsini Sil',
    'max_user_quota' => 'Azami Kullanıcı Kotası',
    'mail.recover_text' => 'Merhaba %s,<br>hesabınız için bir parola sıfırlama istendi. İşlemleri tamamlamak için aşağıdaki bağlantıya tıklayın:<br><br><a href="%s">%s</a><br><br>Parola sıfırlamayı isteyen siz değilseniz bu e-postayı dikkate almayın.',
    'clear_account' => 'Hesabı Temizle',
    'mail.new_account_text_with_pw' => 'Merhaba %s!<br>, %s (<a href="%s">%s</a>) tarihinde sizin için aşağıdaki kimlik bilgileriyle yeni bir hesap oluşturuldu:<br><br>Kullanıcı adı: %s<br>Parola: %s<br><br>Oturum açma sayfasına gitmek için aşağıdaki bağlantıya tıklayın:<br><a href="%s">%s</a>',
    'upload_max_file_size' => 'Azami dosya boyutu şu anda %s.',
    'recover_email_sent' => 'Varsa, belirtilen hesaba bir kurtarma e-postası gönderildi.',
    'cannot_demote' => 'Kendinizi rütbenizi indiremezsiniz.',
    'cannot_write_file' => 'Hedef yol yazılabilir değil.',
    'deleted_orphans' => '%d sahipsiz dosya başarıyla silindi.',
    'gallery' => 'Galeri',
    'table' => 'Tablo',
    'dotted_search' => 'Ara…',
    'time' => 'Zaman',
    'name' => 'Ad',
    'maintenance' => 'Bakım',
    'path_not_writable' => 'Çıkış yolu yazılabilir değil.',
    'already_latest_version' => 'Zaten son sürüme sahipsiniz.',
    'new_version_available' => 'Yeni %s sürümü var!',
    'cannot_retrieve_file' => 'Dosya alınamıyor.',
    'file_size_no_match' => 'İndirilen dosya doğru dosya boyutu ile eşleşmiyor.',
    'check_for_updates' => 'Güncellemeleri denetle',
    'upgrade' => 'Güncelle',
    'updates' => 'Güncellemeler',
    'maintenance_in_progress' => 'Platform bakımda, daha sonra tekrar deneyin…',
    'cancel' => 'İptal',
    'auto_set' => 'Otomatik olarak ayarla',
    'prerelease_channel' => 'Ön Yayın Kanalı',
    'drop_to_upload' => 'Yüklemek için dosyalarınızı buraya bırakın veya tıklayın.',
    'donation' => 'Bağış',
    'donate_text' => 'XBackBone\'u beğendiyseniz, geliştirmeyi desteklemek için bir bağış yapmayı düşünün!',
    'custom_head_html_hint' => 'Bu içerik her sayfanın <head> etiketine eklenecek.',
    'remember_me' => 'Beni hatırla',
    'please_wait' => 'Lütfen bekleyin…',
    'dont_close' => 'Tamamlanana kadar bu sekmeyi kapatmayın.',
    'register_enabled' => 'Kayıtlar etkinleştirildi',
    'hide_by_default' => 'Varsayılan olarak medyayı gizle',
    'settings_saved' => 'Sistem ayarları kaydedildi!',
    'export_data' => 'Veriyi dışarı çıkar',
    'password_recovery' => 'Parolayı kurtar',
    'no_account' => 'Hesabınız yok mu?',
    'register' => 'Kaydol',
    'register_success' => 'Hesap oluşturuldu, bir onay e-postası gönderildi.',
    'default_user_quota' => 'Varsayılan Kullanıcı Kotası',
    'invalid_quota' => 'Varsayılan kullanıcı kotası geçersiz değer.',
    'mail.activate_account' => '%s - Hesap Etkinleştirme',
    'mail.recover_password' => '%s - Parola Kurtarma',
    'account_activated' => 'Hesap etkinleştirildi, artık oturum açabilirsiniz!',
    'quota_enabled' => 'Kullanıcı kotasını etkinleştir',
    'password_repeat' => 'Parolayı Tekrarla',
    'password_match' => 'Parola ve tekrarlanan parola aynı olmalıdır.',
    'password_restored' => 'Parola sıfırlandı.',
    'recalculate_user_quota' => 'Diskten kullanıcı kotasını yeniden hesapla',
    'quota_recalculated' => 'Diskten kullanıcı kotası başarıyla yeniden hesaplandı.',
    'used_space' => 'Kullanılan Alan',
    'delete_selected' => 'Seçilenleri Sil',
    'account_media_deleted' => 'Hesaptaki tüm medya silindi.',
    'danger_zone' => 'Tehlike Bölgesi',
    'recaptcha_failed' => 'reCAPTCHA Başarısız oldu',
    'recaptcha_enabled' => 'reCAPTCHA etkinleştirildi',
    'recaptcha_keys_required' => 'Bütün reCAPTCHA anahtarları gerekli.',
    'only_recaptcha_v3' => 'Yalnızca reCAPTCHA v3 desteklenmektedir.',
    'recaptcha_site_key' => 'reCAPTCHA Site Anahtarı',
    'recaptcha_secret_key' => 'reCAPTCHA Gizli Anahtarı',
    'send_notification' => 'E-posta Bildirimi Gönder',
    'mail.new_account' => '%s - Yeni Hesap Oluşturma',
    'mail.new_account_text_with_reset' => 'Merhaba %s!<br>, %s (<a href="%s">%s</a>) tarihinde sizin için yeni bir hesap oluşturuldu, bir parola belirlemek ve etkinleştirmek için aşağıdaki bağlantıya tıklayın:<br><br><a href="%s">%s</a>',
    'user_create_password' => 'Boş bırakılırsa, kullanıcı e-posta adresine bir bildirim göndermek isteyebilirsiniz.',
    'ldap_cant_connect' => 'LDAP kimlik doğrulama sunucusuna bağlanılamıyor.',
    'no_tags' => 'Etiket eklenmedi',
    'auto_tagging' => 'Otomatik yükleme etiketleme',
    'zip_ext_not_loaded' => 'Gereken "zip" eklentisi yüklenmedi',
    'changelog' => 'Değişiklik Günlüğü (Yama Notları)',
    'show_changelog' => 'Değişiklik günlüğünü göster',
    'confirm' => 'Onayla',
    'user_created' => '"%s" kullanıcısı oluşturuldu!',
    'user_updated' => '"%s" kullanıcısı güncellendi!',
    'profile_updated' => 'Profil başarıyla güncellendi!',
    'user_deleted' => 'Kullanıcı silindi.',
    'cannot_delete' => 'Kendi kullanıcınızı silemezsiniz.',
    'order_by' => 'Sıralama ölçütü…',
    'clean_orphaned_uploads' => 'Sahipsiz Yüklemeleri Temizle',
    'custom_head_html' => 'Özel HTML başlık içeriği',
    'custom_head_set' => 'Özel HTML başlığı uygulandı.',
    'mail.activate_text' => 'Merhaba %s!<br>%s (<a href="%s">%s</a>) hesabınızı oluşturduğunuz için teşekkür ederiz, etkinleştirmek için aşağıdaki bağlantıya tıklayın:<br><br><a href="%s">%s</a>',
    'switch_to' => 'Şuna geç',
    'vanity_url' => 'Özel URL',
];
